pypret.retrieval package
========================

.. automodule:: pypret.pnps
    :no-members:
    
Retrieval algorithms
--------------------
.. autofunction:: pypret.retrieval.retriever.Retriever
.. autoclass:: pypret.retrieval.step_retriever.COPRARetriever
.. autoclass:: pypret.retrieval.step_retriever.PCGPARetriever
.. autoclass:: pypret.retrieval.step_retriever.GPARetriever
.. autoclass:: pypret.retrieval.step_retriever.PIERetriever
.. autoclass:: pypret.retrieval.step_retriever.GPDSCANRetriever
.. autoclass:: pypret.retrieval.nlo_retriever.LMRetriever
.. autoclass:: pypret.retrieval.nlo_retriever.NMRetriever
.. autoclass:: pypret.retrieval.nlo_retriever.DERetriever
.. autoclass:: pypret.retrieval.nlo_retriever.BFGSRetriever

API
---
.. autoclass:: pypret.retrieval.retriever.BaseRetriever
.. autoclass:: pypret.retrieval.step_retriever.StepRetriever
